@@ -78,6 +78,14 @@ class TaskInstance(object):
             pass
         self.commit_time = IntervalTracker(commit_interval)
 
+        commit_num_messages = 1000
+        try:
+            commit_num_messages = int(config.get('commit_num_messages'))
+        except (TypeError, ValueError):
+            pass
+        self.commit_num_messages = commit_num_messages
+        self.messages_since_commit = 0
+
         window_interval = self.task.window_interval
         try:
             window_interval = int(config.get('window_interval'))
@@ -172,6 +180,7 @@ class TaskInstance(object):
             if not self.task.is_windowed:
                 self.offsets.apply_new_offsets()
 
+            self.messages_since_commit += 1
             self.maybe_commit()
 
             gevent.sleep(0)  # to give chance for other greenlets to run
@@ -185,10 +194,11 @@ class TaskInstance(object):
             self.offsets.apply_new_offsets()
 
     def maybe_commit(self):
-        if self.commit_time:
+        if self.commit_time or self.messages_since_commit >= self.commit_num_messages:
             self.commit()
 
             self.commit_time.reset()
+            self.messages_since_commit = 0
 
     def commit(self):
         # commit state
